import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeCollapsible';
var CONTENT_CLASS = BASE_CLASS + "-content";
var CONTAINER_BUTTON_CLASS = BASE_CLASS + "-container";
var COLLAPSED_CLASS = 'is-collapsed';
var BUTTON_CLASS = BASE_CLASS + "-btn";
var BUTTON_CONTENT_CLASS = BUTTON_CLASS + "-content";
var ICON_CLASS = BASE_CLASS + "-icon";
var MIN_HEIGHT = 100; // px

var MoleculeCollapsible =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(MoleculeCollapsible, _Component);

  function MoleculeCollapsible(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _this.toggleCollapse = function () {
      var _this$state = _this.state,
          collapsed = _this$state.collapsed,
          showButton = _this$state.showButton;
      var _this$props = _this.props,
          onClose = _this$props.onClose,
          onOpen = _this$props.onOpen;

      if (showButton) {
        _this.setState({
          collapsed: !collapsed
        });

        collapsed && onOpen() || onClose();
      }
    };

    _this.childrenContainer = React.createRef();
    _this.state = {
      collapsed: true,
      showButton: true,
      maxHeight: MIN_HEIGHT
    };
    return _this;
  }

  var _proto = MoleculeCollapsible.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var offsetHeight = this.childrenContainer.current.offsetHeight;
    this.setState({
      showButton: offsetHeight >= this.props.height,
      maxHeight: offsetHeight
    });
  };

  _proto.render = function render() {
    var _cx, _cx2, _cx3, _cx4;

    var _this$state2 = this.state,
        collapsed = _this$state2.collapsed,
        showButton = _this$state2.showButton,
        maxHeight = _this$state2.maxHeight;
    var _this$props2 = this.props,
        children = _this$props2.children,
        height = _this$props2.height,
        icon = _this$props2.icon,
        showText = _this$props2.showText,
        hideText = _this$props2.hideText,
        withGradient = _this$props2.withGradient,
        withTransition = _this$props2.withTransition;
    var wrapperClassName = cx("" + BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--withGradient"] = withGradient, _cx[COLLAPSED_CLASS] = collapsed, _cx));
    var iconClassName = cx("" + ICON_CLASS, (_cx2 = {}, _cx2[COLLAPSED_CLASS] = collapsed, _cx2));
    var containerClassName = cx("" + CONTAINER_BUTTON_CLASS, (_cx3 = {}, _cx3[CONTAINER_BUTTON_CLASS + "--withGradient"] = withGradient, _cx3[COLLAPSED_CLASS] = collapsed, _cx3));
    var contentClassName = cx("" + CONTENT_CLASS, (_cx4 = {}, _cx4[CONTENT_CLASS + "--withTransition"] = withTransition, _cx4));
    var containerHeight = showButton && collapsed ? height + "px" : maxHeight + "px";
    return React.createElement("div", {
      className: wrapperClassName
    }, React.createElement("div", {
      className: contentClassName,
      style: {
        maxHeight: "" + containerHeight
      }
    }, React.createElement("div", {
      ref: this.childrenContainer
    }, children)), showButton && React.createElement("div", {
      className: containerClassName
    }, React.createElement("button", {
      type: "button",
      className: BUTTON_CLASS,
      onClick: this.toggleCollapse
    }, React.createElement("span", {
      className: BUTTON_CONTENT_CLASS,
      tabIndex: "-1"
    }, collapsed ? showText : hideText, React.createElement("span", {
      className: iconClassName
    }, icon)))));
  };

  return MoleculeCollapsible;
}(Component);

MoleculeCollapsible.displayName = 'MoleculeCollapsible';
MoleculeCollapsible.defaultProps = {
  height: MIN_HEIGHT,
  withGradient: true,
  withTransition: true,
  onOpen: function onOpen() {},
  onClose: function onClose() {}
};
export default MoleculeCollapsible;